# padding, used for unknown symbols and in training for no symbols
# DEFAULT_PADDING_SYMBOL = "_"

DEFAULT_CSV_SEPERATOR = "\t"

NOT_INFERABLE_SYMBOL_MARKER = "█"

SPACE_DISPLAYABLE = "␣"
